=== modified file '__init__.py'
--- __init__.py	2008-07-04 08:05:17 +0000
+++ __init__.py	2008-07-25 15:42:45 +0000
@@ -22,6 +22,7 @@
 gconflicts        GTK+ conflicts. 
 gdiff             Show differences in working tree in a GTK+ Window. 
 ginit             Initialise a new branch.
+gmerge            GTK+ merge dialog
 gmissing          GTK+ missing revisions dialog. 
 gpreferences      GTK+ preferences dialog. 
 gpush             GTK+ push.
@@ -451,6 +452,29 @@
         dialog.run()
 
 
+class cmd_gmerge(Command):
+    """ GTK+ merge dialog
+    
+    """
+    takes_args = ["merge_from_path?"]
+    def run(self, merge_from_path=None):
+        from bzrlib import workingtree
+        from bzrlib.plugins.gtk.dialog import error_dialog
+        from bzrlib.plugins.gtk.merge import MergeDialog
+        
+        (wt, path) = workingtree.WorkingTree.open_containing('.')
+        old_tree = wt.branch.repository.revision_tree(wt.branch.last_revision())
+        delta = wt.changes_from(old_tree)
+        if len(delta.added) or len(delta.removed) or len(delta.renamed) or len(delta.modified):
+            error_dialog(_i18n('There are local changes in the branch'),
+                         _i18n('Please commit or revert the changes before merging.'))
+        else:
+            parent_branch_path = wt.branch.get_parent()
+            merge = MergeDialog(wt, path, parent_branch_path)
+            response = merge.run()
+            merge.destroy()
+
+
 class cmd_gmissing(Command):
     """ GTK+ missing revisions dialog.
 
@@ -514,6 +538,7 @@
     cmd_gconflicts, 
     cmd_gdiff,
     cmd_ginit,
+    cmd_gmerge,
     cmd_gmissing, 
     cmd_gpreferences, 
     cmd_gpush, 

=== modified file 'merge.py'
--- merge.py	2008-07-18 18:21:26 +0000
+++ merge.py	2008-07-25 15:42:45 +0000
@@ -46,7 +46,10 @@
         self.wt = wt
         self.wtpath = wtpath
         
-        directory = os.path.dirname(self.wt.abspath(self.wtpath))
+        if default_branch_path and os.path.isdir(default_branch_path.partition('file://')[2]):
+            directory = default_branch_path.partition('file://')[2]
+        else:
+            directory = os.path.dirname(self.wt.abspath(self.wtpath))
         
         # Create widgets
         self._hbox = gtk.HBox()

